(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('prismjs'), require('@angular/common'), require('@angular/core'), require('@angular/common/http'), require('marked'), require('rxjs'), require('rxjs/operators')) :
    typeof define === 'function' && define.amd ? define('@ng-tangram/markdown', ['exports', 'prismjs', '@angular/common', '@angular/core', '@angular/common/http', 'marked', 'rxjs', 'rxjs/operators'], factory) :
    (global = global || self, factory((global.nt = global.nt || {}, global.nt.markdown = {}), global.Prism, global.ng.common, global.ng.core, global.ng.common.http, global.marked, global.rxjs, global.rxjs.operators));
}(this, (function (exports, prismjs, common, core, http, marked, rxjs, operators) { 'use strict';

    marked = marked && marked.hasOwnProperty('default') ? marked['default'] : marked;

    var NT_MARKDOWN_ENGINE = new core.InjectionToken('nt-markdown-engine');

    var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var __param = (this && this.__param) || function (paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); }
    };
    var NtMarkdownComponent = (function () {
        function NtMarkdownComponent(_platformId, _markdownEngine, _elementRef) {
            this._platformId = _platformId;
            this._markdownEngine = _markdownEngine;
            this._elementRef = _elementRef;
        }
        Object.defineProperty(NtMarkdownComponent.prototype, "path", {
            get: function () { return this._path; },
            set: function (value) { this._path = value || ''; },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(NtMarkdownComponent.prototype, "data", {
            get: function () { return this._data; },
            set: function (value) { this._data = value; },
            enumerable: true,
            configurable: true
        });
        NtMarkdownComponent.prototype.ngOnChanges = function (changes) {
            var pathChange = changes.path;
            var dataChange = changes.data;
            if (pathChange && !pathChange.firstChange) {
                this._pathChange();
            }
            if (dataChange && !dataChange.firstChange) {
                this._dataChange();
            }
        };
        NtMarkdownComponent.prototype.ngAfterViewInit = function () {
            if (this.path) {
                this._pathChange();
            }
            else {
                this._dataChange();
            }
        };
        NtMarkdownComponent.prototype._dataChange = function () {
            var _this = this;
            if (this.data) {
                this._markdownEngine
                    .compile(this.data)
                    .subscribe(function (markdown) { return _this._setMarkdownHtml(markdown); });
            }
            else {
                this._setMarkdownHtml('');
            }
        };
        NtMarkdownComponent.prototype._pathChange = function () {
            var _this = this;
            if (this.path) {
                this._ext = this.path && this.path.split('.').splice(-1).join();
                this._markdownEngine.getContent(this.path).subscribe(function (content) {
                    content = _this._ext !== 'md' ? ['```', _this._ext + "\n" + content + "\n", '```'].join() : content;
                    _this._markdownEngine.compile(_this._prepare(content)).subscribe(function (markdown) { return _this._setMarkdownHtml(markdown); });
                }, function (error) { return _this._handleError(error); });
            }
        };
        NtMarkdownComponent.prototype._handleError = function (error) {
            return Promise.reject(error.message || error);
        };
        NtMarkdownComponent.prototype._prepare = function (raw) {
            var _this = this;
            if (!raw) {
                return '';
            }
            if (this._ext === 'md' || !this.path) {
                var isCodeBlock_1 = false;
                return raw.split('\n').map(function (line) {
                    if (_this._trimLeft(line).substring(0, 3) === "```") {
                        isCodeBlock_1 = !isCodeBlock_1;
                    }
                    return isCodeBlock_1 ? line : line.trim();
                }).join('\n');
            }
            return raw.replace(/\"/g, '\'');
        };
        NtMarkdownComponent.prototype._postpare = function () {
            if (common.isPlatformBrowser(this._platformId)) {
                prismjs.highlightAll(false);
            }
        };
        NtMarkdownComponent.prototype._setMarkdownHtml = function (markdown) {
            this._elementRef.nativeElement.innerHTML = markdown;
            this._postpare();
        };
        NtMarkdownComponent.prototype._trimLeft = function (line) {
            return line.replace(/^\s+|\s+$/g, '');
        };
        NtMarkdownComponent.ctorParameters = function () { return [
            { type: Object, decorators: [{ type: core.Inject, args: [core.PLATFORM_ID,] }] },
            { type: undefined, decorators: [{ type: core.Inject, args: [NT_MARKDOWN_ENGINE,] }] },
            { type: core.ElementRef }
        ]; };
        __decorate([
            core.Input()
        ], NtMarkdownComponent.prototype, "path", null);
        __decorate([
            core.Input()
        ], NtMarkdownComponent.prototype, "data", null);
        NtMarkdownComponent = __decorate([
            core.Component({
                selector: 'nt-markdown, [nt-markdown]',
                template: '',
                encapsulation: core.ViewEncapsulation.None,
                host: {
                    class: 'nt-markdown'
                }
            }),
            __param(0, core.Inject(core.PLATFORM_ID)),
            __param(1, core.Inject(NT_MARKDOWN_ENGINE))
        ], NtMarkdownComponent);
        return NtMarkdownComponent;
    }());

    var __decorate$1 = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var NtMarkdownModule = (function () {
        function NtMarkdownModule() {
        }
        NtMarkdownModule = __decorate$1([
            core.NgModule({
                imports: [common.CommonModule],
                declarations: [NtMarkdownComponent],
                exports: [NtMarkdownComponent]
            })
        ], NtMarkdownModule);
        return NtMarkdownModule;
    }());

    var NT_MARKED_DEFAULT_OPTIONS = {
        gfm: true,
        breaks: false,
        pedantic: false,
        smartLists: true,
        smartypants: false
    };
    var NT_MARKED_OPTIONS = new core.InjectionToken('nt-marked-options');

    var __decorate$2 = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var __param$1 = (this && this.__param) || function (paramIndex, decorator) {
        return function (target, key) { decorator(target, key, paramIndex); }
    };
    var NtMarkedEngine = (function () {
        function NtMarkedEngine(http, options) {
            if (options === void 0) { options = {}; }
            this.http = http;
            this._renderer = new marked.Renderer();
            this.extendRenderer();
            this.setMarkedOptions(options);
        }
        Object.defineProperty(NtMarkedEngine.prototype, "renderer", {
            get: function () { return this._renderer; },
            enumerable: true,
            configurable: true
        });
        NtMarkedEngine.prototype.getContent = function (path) {
            return this.http.get(path, { responseType: 'text' }).pipe(operators.catchError(this.handleError));
        };
        NtMarkedEngine.prototype.setMarkedOptions = function (options) {
            options.renderer = this._renderer;
            marked.setOptions(options);
        };
        NtMarkedEngine.prototype.compile = function (data) { return rxjs.of(marked(data)); };
        NtMarkedEngine.prototype.handleError = function (error) {
            var errMsg;
            if (error instanceof http.HttpResponse) {
                var body = error.body || '';
                var err = body.error || JSON.stringify(body);
                errMsg = error.status + " - " + (error.statusText || '') + " " + err;
            }
            else {
                errMsg = error.message ? error.message : error.toString();
            }
            return rxjs.throwError(errMsg);
        };
        NtMarkedEngine.prototype.extendRenderer = function () {
            this._renderer.heading = function (text, level) {
                text = text.trim();
                return "<h" + level + " id=\"" + text.replace(/\<a[^>]*?\>((.|\n)*?)\<\/a\>/g, '$1').replace(/ +/g, '-') + "\">\n\t\t\t\t\t\t" + text + "\n\t\t\t\t\t</h" + level + ">";
            };
            this._renderer.listitem = function (text) {
                if (/^\s*\[[x ]\]\s*/.test(text)) {
                    var checkedStyle = 'vertical-align: middle; margin: 0 0.2em 0.25em -1.6em; font-size: 16px;';
                    text = text
                        .replace(/^\s*\[ \]\s*/, "<input type=\"checkbox\" style=\"" + checkedStyle + "\" disabled>")
                        .replace(/^\s*\[x\]\s*/, "<input type=\"checkbox\" style=\"" + checkedStyle + "\" checked disabled>");
                    return "<li style=\"list-style: none\">" + text + "</li>";
                }
                else {
                    return "<li>" + text + "</li>";
                }
            };
        };
        NtMarkedEngine.ctorParameters = function () { return [
            { type: http.HttpClient },
            { type: undefined, decorators: [{ type: core.Optional }, { type: core.Inject, args: [NT_MARKED_OPTIONS,] }] }
        ]; };
        NtMarkedEngine = __decorate$2([
            core.Injectable(),
            __param$1(1, core.Optional()), __param$1(1, core.Inject(NT_MARKED_OPTIONS))
        ], NtMarkedEngine);
        return NtMarkedEngine;
    }());

    var __decorate$3 = (this && this.__decorate) || function (decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    };
    var ɵ0 = NT_MARKED_DEFAULT_OPTIONS;
    var NtMarkedEngineModule = (function () {
        function NtMarkedEngineModule() {
        }
        NtMarkedEngineModule = __decorate$3([
            core.NgModule({
                imports: [http.HttpClientModule],
                providers: [
                    { provide: NT_MARKDOWN_ENGINE, useClass: NtMarkedEngine },
                    { provide: NT_MARKED_OPTIONS, useValue: ɵ0 },
                ],
            })
        ], NtMarkedEngineModule);
        return NtMarkedEngineModule;
    }());

    exports.NT_MARKDOWN_ENGINE = NT_MARKDOWN_ENGINE;
    exports.NT_MARKED_DEFAULT_OPTIONS = NT_MARKED_DEFAULT_OPTIONS;
    exports.NT_MARKED_OPTIONS = NT_MARKED_OPTIONS;
    exports.NtMarkdownComponent = NtMarkdownComponent;
    exports.NtMarkdownModule = NtMarkdownModule;
    exports.NtMarkedEngine = NtMarkedEngine;
    exports.NtMarkedEngineModule = NtMarkedEngineModule;
    exports.ɵ0 = ɵ0;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=markdown.umd.js.map
